Miscellaneous
~~~~~~~~~~~~~

**Background Concepts for Murano**

.. toctree::
   :maxdepth: 1

   workflow


**Tutorials**

.. toctree::
   :maxdepth: 1

   image_builders/index
   test_docs


**Guidelines**

.. toctree::
   :maxdepth: 1

   guidelines

**Gerrit review dashboard**

.. toctree::
   :maxdepth: 1

   murano_gerrit_dashboard


**API specification**

.. toctree::
   :maxdepth: 1

   specification/index
